
# SUMOnet

SUMOnet that take the peptide sequence centered on the candidate SUMOylation site as input and predict whether the lysine could be SUMOylated

## Quick Install

```sh
pip install sumonet
```

## Requirements

> We strongly recomment using virtual environment for these package requirements.

> All packages will be installed automatically by pip.

> The following package versions were used to get evaluation results in our paper.

```python
python 3.6.6
numpy 1.19.5
scikit-learn 0.24.2
joblib 1.0.0
pandas 1.0.5
epitopepredict 0.5.0
tensorflow 2.4.0
keras 2.3.1
```

## Detailed Tutorial For Use Cases

Please visit our [Tutorial Page](https://sumonet.onrender.com/)


## Citation

If you use SUMOnet in your work, please do cite us:

[Dilekoglu, B., Tastan, O.: Sumonet: Deep sequential prediction of sumoylation sites. bioRxiv (2023).](https://www.biorxiv.org/content/10.1101/2023.08.25.554749v1)

## License

[Academic Free License ("AFL") v. 3.0](https://choosealicense.com/licenses/afl-3.0/#)